@@ -1,5 +1,5 @@
 /**********************************************************************
- * Copyright (C) 2014-2023 MX Authors
+ * Copyright (C) 2014-2024 MX Authors
  *
  * Authors: Adrian
  *          MX Linux <http://mxlinux.org>
@@ -19,9 +19,7 @@
  * You should have received a copy of the GNU General Public License
  * along with MX Tools.  If not, see <http://www.gnu.org/licenses/>.
  **********************************************************************/
-
-#ifndef FLATBUTTON_H
-#define FLATBUTTON_H
+#pragma once
 
 #include <QPushButton>
 
@@ -40,5 +38,3 @@ protected:
     void enterEvent(QEvent *e) override;
     void leaveEvent(QEvent *e) override;
 };
-
-#endif // FLATBUTTON_H
